clear all
set more off
set mem 6g
set scheme sol, perm

**Path Names: change path names to your local directories
global ecpublic "pathwherereplicationfolderis"
global output "youroutputfile"


*********
*FIGURES*
*********
************************************************
*** Figure 1
************************************************
use "$ecpublic\miansufieconometrica_countylevel", clear
# delimit ;
graph twoway (scatter CCemp2_0709_2 netwp_h , msize(small))
(lfit CCemp2_0709_2 netwp_h, lw(medthick) lc(black))
(lowess CCemp2_0709_2 netwp_h, lp(solid) lc(black))
if total>50000 & CCemp2_0709_2<0.2 & netwp_h>=-0.3,
xtitle("Change in housing net worth, 2006-2009", size(medsmall)) 
ytitle("Non-Tradable Employment Growth 07Q1-09Q1" "(restaurants & retail)", size(medsmall)) 
xlabel(#10, labsize(small)) ylabel(, labsize(small)) legend(off);
# delimit cr
graph save "$output\Figure1a", replace

# delimit ;
graph twoway (scatter CH2emp2_0709_1 netwp_h , msize(small))
(lfit CH2emp2_0709_1 netwp_h, lw(medthick) lc(black))
(lowess CH2emp2_0709_1 netwp_h, lp(solid) lc(black))
if total>50000 & abs(CH2emp2_0709_1)<0.2 & netwp_h>=-0.3,
xtitle("Change in housing net worth, 2006-2009", size(medsmall)) 
ytitle("Non-Tradable Sector Employment Growth 07Q1-09Q1" "(based on low geographical concentration)", size(medsmall)) 
xlabel(#10, labsize(small)) ylabel(, labsize(small)) legend(off);
# delimit cr
graph save "$output\Figure1b", replace

# delimit ;
graph combine "$output\Figure1a" "$output\Figure1b" 
, col(2) xsize(10) ysize(6);
# delimit cr
graph save "$output\Figure1", replace


****************************************
***** Figure 2
****************************************
use "$ecpublic\miansufieconometrica_countylevel", clear

# delimit ;
graph twoway (scatter CCemp2_0709_1 netwp_h , msize(vsmall))
(lfit CCemp2_0709_1 netwp_h, lw(medthick) lc(black))
if total>50000 & abs(CCemp2_0709_1)<0.6  & netwp_h>-0.3,
xtitle("Change in housing net worth, 2006-2009", size(small)) 
ytitle("Tradable Empl Growth" "07-09, trade based)", size(small)) 
xlabel(#10, labsize(vsmall)) ylabel(, labsize(vsmall)) legend(off);
# delimit cr
graph save "$output\Figure2a", replace


# delimit ;
graph twoway (scatter CH2emp2_0709_4 netwp_h , msize(vsmall))
(lfit CH2emp2_0709_4 netwp_h, lw(medthick) lc(black))
if total>50000 & abs(CH2emp2_0709_4)<0.6  & netwp_h>-0.3,
xtitle("Change in housing net worth, 2006-2009", size(small)) 
ytitle("Tradable Empl Growth" "07-09, geog. conc. based)", size(small)) 
xlabel(#10, labsize(vsmall)) ylabel(, labsize(vsmall)) legend(off);
# delimit cr
graph save "$output\Figure2b", replace

# delimit ;
graph twoway (scatter Cwage_0709 netwp_h, msize(vsmall))
(lfit Cwage_0709 netwp_h, lw(medthick) lc(black))
if total>50000 & netwp_h>-0.3 & Cwage_0709>-0.2,
xtitle("Change in housing net worth, 2006-2009", size(small)) 
ytitle("Wage growth 07Q1-09Q1" "(CBP)", size(small)) 
xlabel(#10, labsize(vsmall)) ylabel(, labsize(vsmall)) legend(off);
# delimit cr
graph save "$output\Figure2c", replace

label variable Cwagehr_Wmean0709 "mean hourly wage growth (ACS)"
# delimit ;
graph twoway (scatter Cwagehr_Wmean0709 netwp_h, msize(vsmall))
(lfit Cwagehr_Wmean0709 netwp_h, lw(medthick) lc(black))
if total>50000 & netwp_h>-0.3,
xtitle("Change in housing net worth, 2006-2009", size(small)) 
ytitle("Hourly Wage growth" "07-09 (ACS)", size(small)) 
xlabel(#10, labsize(vsmall)) ylabel(, labsize(vsmall)) legend(off);
# delimit cr
graph save "$output\Figure2d", replace

gen pop0709=log(pop2009)-log(pop2007)
# delimit ;
graph twoway (scatter pop0709 netwp_h, msize(vsmall))
(lfit pop0709 netwp_h, lw(medthick) lc(black))
if pop0709<=0.1 & total>50000 & netwp_h>-0.3
,
xtitle("Change in housing net worth, 2006-2009", size(small)) 
ytitle("Pop. Growth 07-09" "(Census)", size(small)) 
xlabel(#10, labsize(vsmall)) ylabel(, labsize(vsmall)) legend(off);
# delimit cr
graph save "$output\Figure2e", replace

# delimit ;
graph twoway (scatter Clf_0709 netwp_h, msize(vsmall))
(lfit Clf_0709 netwp_h, lw(medthick) lc(black))
if total>50000 & abs(Clf_0709)<0.1 & netwp_h>-0.3,
xtitle("Change in housing net worth, 2006-2009", size(small)) 
ytitle("Labor Force Growth" "(07-09)", size(small)) 
xlabel(#10, labsize(vsmall)) ylabel(, labsize(vsmall)) legend(off);
# delimit cr
graph save "$output\Figure2f", replace

# delimit ;
graph combine 
"$output\Figure2a" "$output\Figure2b" 
"$output\Figure2c" "$output\Figure2d" 
"$output\Figure2e" "$output\Figure2f" 
, col(2) xsize(7) ysize(8);
# delimit cr
graph save "$output\Figure2", replace


*********
*TABLES *
*********

******************************************
*** Table 1: Industry Classification  ****
******************************************
*Panel A
use "$ecpublic\miansufieconometrica_countyindustrylevel", clear
egen ntag=tag(naics)
keep if ntag==1
keep if Iemp2_2007!=.
egen totalemp=sum(Iemp2_2007)
gen Iempshare07=(Iemp2_2007/totalemp)*100
*Listing of industries
sort indcat nontradable_strict naics
gsort indcat nontradable_strict -Iempshare07
keep indcat nontradable_strict naics industry Iempshare07 Ihcat2
by indcat: keep if _n<=20
outsheet using "$output\Table1_a.csv", comma replace

*Panel B: Geog conc
use "$ecpublic\miansufieconometrica_countyindustrylevel", clear
egen ntag=tag(naics)
keep if ntag==1
gen tradable=indcat==1
gen nontradable=indcat==2
gsort -Iherf
keep nontradable tradable naics industry
keep if _n<=20
outsheet using "$output\Table1bi.csv", comma replace

use "$ecpublic\miansufieconometrica_countyindustrylevel", clear
egen ntag=tag(naics)
keep if ntag==1
gen tradable=indcat==1
gen nontradable=indcat==2
sort Iherf
keep nontradable tradable naics industry
keep if _n<=20
outsheet using "$output\Table1bii.csv", comma replace


*****************************
*****  Table 2
*****  Summary Stats
*****************************
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if netwp_h!=.
*Unweighted (first 5 columns)
# delimit ;
tabstat 
netwp_h total Clf_0709 Cemp2_2007 Cemp2_0709 Cwage_2007 Cwage_0709 elasticity  
Cwagehr_Wmean2007 Cwagehr_p??2007 Cwagehr_median2007 Cwagehr_p??0709 Cwagehr_median0709 Cwagehr_Wmean0709
, stat(n mean sd p10  p90) c(s);
# delimit cr
tabstat CCemp2_0709_2, stat(n mean sd p10 p90) c(s)
tabstat CFemp2_0709, stat(n mean sd p10 p90) c(s)
tabstat CCemp2_0709_1, stat(n mean sd p10 p90) c(s)
tabstat CCemp2_0709_3, stat(n mean sd p10 p90) c(s)
tabstat CCemp2_0709_0, stat(n mean sd p10 p90) c(s)

*wtd means
# delimit ;
tabstat netwp_h total Clf_0709 Cemp2_2007 Cemp2_0709 Cwage_2007 Cwage_0709 elasticity  
Cwagehr_Wmean2007 Cwagehr_p??2007 Cwagehr_median2007 Cwagehr_p??0709 Cwagehr_median0709 Cwagehr_Wmean0709
[aw=total], stat(mean sd) c(s);
# delimit cr
*Industry break down of employment and employment growth
tabstat CCemp2_0709_2 [aw=total], stat(mean sd) c(s)
tabstat CFemp2_0709 [aw=total], stat(mean sd) c(s)
tabstat CCemp2_0709_1 [aw=total], stat(mean sd) c(s)
tabstat CCemp2_0709_3 [aw=total], stat(mean sd) c(s)
tabstat CCemp2_0709_0 [aw=total], stat(mean sd) c(s)

*Industry level summary stats
use "$ecpublic\miansufieconometrica_countyindustrylevel", clear
egen ntag=tag(naics)
keep if ntag==1
tabstat Iherf, stat(n mean sd p10 p90) c(s)
tabstat Iherf [aw=Iemp2_2007], stat(mean sd) c(s)


*************************************************************
*****  Table 3: 
*** Housing net worth shock And non-tradable Employment
*************************************************************
use "$ecpublic\miansufieconometrica_countylevel", clear
*main
reg CCemp2_0709_2 netwp_h [aw=total], cluster(state) robust
reg CH2emp2_0709_1 netwp_h [aw=total], cluster(state)
*ols 2-digit shock version
reg CCemp2_0709_2 netwp_h C2D06share* [aw=total], cluster(state) robust
reg CH2emp2_0709_1 netwp_h C2D06share* [aw=total], cluster(state)
**IV with 2-digit employment share shocks
ivreg CCemp2_0709_2 (netwp_h=elasticity) C2D06share* [aw=total], cluster(state) robust
ivreg CH2emp2_0709_1 (netwp_h=elasticity) C2D06share* [aw=total], cluster(state)
*additional column with elasticity demographic controls
ivreg CCemp2_0709_2 (netwp_h=elasticity) white medhhinc owner educ_lths educ_hs unemp pov urban C2D06share* [aw=total], cluster(state) robust
**2007 construction share with interaction
gen netwp_cons=C_const*netwp_h
reg CCemp2_0709_2 netwp_h C_const netwp_cons C2D06share* [aw=total], cluster(state) robust
reg CH2emp2_0709_1 netwp_h C_const netwp_cons C2D06share* [aw=total], cluster(state)
*controlling for construction growth in 07-09
gen Cconsemp_0709=CCemp2_0709_3
reg CCemp2_0709_2 netwp_h CCemp2_0709_3 C2D06share* [aw=total], cluster(state) robust


****Table 3: Reporting Standard Errors wtih Spatial Correlation ****
*the ijth element of idmat contains the inverse of the distance between these points, calculated from the coordinate variables represent logitude and latitude.
*col 1
qui {
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CCemp2_0709_2!=. & netwp_h!=. & centrdlon!=.
*transforming each variable to account for weights
foreach var of varlist CCemp2_0709_2 netwp_h {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml CCemp2_0709_2wt conswt netwp_hwt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*check: replicating col1 coeff
reg CCemp2_0709_2wt conswt netwp_hwt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 1: " sqrt(V[2,2])

*col 2
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CH2emp2_0709_1!=. & netwp_h!=. & centrdlon!=.
foreach var of varlist CH2emp2_0709_1 netwp_h {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml CH2emp2_0709_1wt conswt netwp_hwt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col2 coeff
reg CH2emp2_0709_1wt conswt netwp_hwt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 2: " sqrt(V[2,2])

*col3
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CCemp2_0709_2!=. & netwp_h!=. & centrdlon!=.
reg CCemp2_0709_2 C2D06share* [aw=total] , cluster(state) robust
predict temp1, resid
reg netwp_h C2D06share* [aw=total] , cluster(state) robust
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col3 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 3: " sqrt(V[1,1])

*col 4
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CH2emp2_0709_1!=. & netwp_h!=. & centrdlon!=.
reg CH2emp2_0709_1 C2D06share* [aw=total] , cluster(state)
predict temp1, resid
reg netwp_h C2D06share* [aw=total], cluster(state)
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col4 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 4: " sqrt(V[1,1])

*col 5
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CCemp2_0709_2!=. & netwp_h!=. & elasticity!=. & centrdlon!=.
reg netwp_h elasticity C2D06share* [aw=total], cluster(state) robust
predict tempfs, xb
reg CCemp2_0709_2 C2D06share* [aw=total], cluster(state) robust
predict temp1, resid
reg tempfs C2D06share* [aw=total], cluster(state) robust
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col5 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 5: " sqrt(V[1,1])

*col 6
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CH2emp2_0709_1!=. & netwp_h!=. & elasticity!=. & centrdlon!=.
reg netwp_h elasticity C2D06share* [aw=total], cluster(state)
predict tempfs, xb
reg CH2emp2_0709_1 C2D06share* [aw=total], cluster(state) robust
predict temp1, resid
reg tempfs C2D06share* [aw=total], cluster(state) robust
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col6 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 6: " sqrt(V[1,1])


*col 7
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CCemp2_0709_2!=. & netwp_h!=. & elasticity!=. & C2D06share1!=. & centrdlon!=.
*standard error
keep if CCemp2_0709_2!=. & netwp_h!=. & elasticity!=.
reg netwp_h elasticity C2D06share* white medhhinc owner educ_lths educ_hs unemp pov urban [aw=total], cluster(state) robust
predict tempfs, xb
reg CCemp2_0709_2 C2D06share* white medhhinc owner educ_lths educ_hs unemp pov urban [aw=total], cluster(state) robust
predict temp1, resid
reg tempfs C2D06share* white medhhinc owner educ_lths educ_hs unemp pov urban [aw=total], cluster(state) robust
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col7 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 7: " sqrt(V[1,1])


*col8
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CCemp2_0709_2!=. & netwp_h!=. & centrdlon!=.
gen netwp_cons=C_const*netwp_h
reg CCemp2_0709_2 C_const netwp_cons C2D06share* [aw=total], cluster(state) robust
predict temp1, resid
reg netwp_h C_const netwp_cons C2D06share* [aw=total], cluster(state) robust
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col8 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 8: " sqrt(V[1,1])

*col 9
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CH2emp2_0709_1!=. & netwp_h!=. & centrdlon!=.
gen netwp_cons=C_const*netwp_h
reg CH2emp2_0709_1 C_const netwp_cons C2D06share* [aw=total], cluster(state)
predict temp1, resid
reg netwp_h C_const netwp_cons C2D06share* [aw=total], cluster(state)
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col9 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 9: " sqrt(V[1,1])

*col10
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if CCemp2_0709_2!=. & netwp_h!=. & centrdlon!=.
gen Cconsemp_0709=CCemp2_0709_3
reg CCemp2_0709_2 Cconsemp_0709 C2D06share* [aw=total], cluster(state) robust
predict temp1, resid
reg netwp_h Cconsemp_0709 C2D06share* [aw=total], cluster(state) robust
predict temp2, resid
foreach var of varlist temp1 temp2 {
gen `var'wt=`var'*sqrt(total)
}
gen conswt=sqrt(total)
spmat idistance idmat1  centrdlon centrdlat, id(fips) dfunction(dhaversine) replace
spreg ml temp1wt temp2wt conswt, id(fips) dlmat(idmat1) elmat(idmat1) nocon
matrix V=get(VCE)
*replicating col10 coeff
reg temp1wt temp2wt conswt, cluster(state) nocon
noisily disp "Spatially corrected standard error for col 10: " sqrt(V[1,1])
}

**********************************************
***  Table 4: Testing credit supply story  ***
**********************************************
use "$ecpublic\miansufieconometrica_countylevel", clear
**Panel A: OLS by establishment size
reg CCemp2_1_4_0709_2 netwp_h [aw=total], cluster(state) robust
reg CCemp2_5_9_0709_2 netwp_h [aw=total], cluster(state) robust
reg CCemp2_10_19_0709_2 netwp_h [aw=total], cluster(state) robust
reg CCemp2_20_49_0709_2 netwp_h [aw=total], cluster(state) robust
reg CCemp2_50_99_0709_2 netwp_h [aw=total], cluster(state) robust
reg CCemp2_100plus_0709_2 netwp_h [aw=total], cluster(state) robust
**Panel B: IV by establishment size
ivreg CCemp2_1_4_0709_2 (netwp_h=elasticity) [aw=total], cluster(state) robust
ivreg CCemp2_5_9_0709_2 (netwp_h=elasticity) [aw=total], cluster(state) robust
ivreg CCemp2_10_19_0709_2 (netwp_h=elasticity) [aw=total], cluster(state) robust
ivreg CCemp2_20_49_0709_2 (netwp_h=elasticity) [aw=total], cluster(state) robust
ivreg CCemp2_50_99_0709_2 (netwp_h=elasticity) [aw=total], cluster(state) robust
ivreg CCemp2_100plus_0709_2 (netwp_h=elasticity) [aw=total], cluster(state) robust
**Panel C: by local versus national banks
use "$ecpublic\miansufieconometrica_countylevel", clear
keep if netwp_h!=.
sum Clocalshare, d
gen national=1 if Clocalshare<r(p50)
gen local=1 if Clocalshare>=r(p50)
sum Clocalshare if national==1
sum Clocalshare if local==1
*first stage
reg netwp_h elasticity [aw=total], cluster(state) robust
predict netwpp, xb
*column starts
reg CCemp2_0709_2 netwp_h [aw=total] if national==1, cluster(state) robust
reg CCemp2_0709_2 netwpp [aw=total] if national==1, cluster(state) robust
reg CCemp2_0709_2 netwp_h [aw=total] if local==1, cluster(state) robust
reg CCemp2_0709_2 netwpp [aw=total] if local==1, cluster(state) robust



**********************************************************************
*****  Table 5: Housing net worth shock and tradable employment ******
**********************************************************************
use "$ecpublic\miansufieconometrica_countylevel", clear
*main
reg CCemp2_0709_1 netwp_h [aw=total], cluster(state) robust
reg CH2emp2_0709_4 netwp_h [aw=total], cluster(state)
*ols 2-digit shock version
reg CCemp2_0709_1 netwp_h C2D06share* [aw=total], cluster(state) robust
reg CH2emp2_0709_4 netwp_h C2D06share* [aw=total], cluster(state)

*County-Industry Data smooth tradability definition
use "$ecpublic\miansufieconometrica_countyindustrylevel", clear
gen netwpherf=Iherf*netwp_h
reg CIemp2_0709 netwp_h Iherf netwpherf [aw=CIemp2_2007] , cluster(state)
keep if netwp_h!=.
xi: areg CIemp2_0709 netwp_h Iherf netwpherf i.naics [aw=CIemp2_2007] , cluster(state) absorb(fips)
gen logexpwkr=log(export_worker)
replace export_worker=export_worker/1000000
gen netwpexpwk=export_worker*netwp_h
gen netwplogexpwk=logexpwkr*netwp_h
keep if indcat==1
*export_worker interactions: columns 7 and 8
reg CIemp2_0709 netwp_h export_worker netwpexpwk if indcat==1 [aw=CIemp2_2007] , cluster(state)
xi: areg CIemp2_0709 netwp_h export_worker netwpexpwk i.naics if indcat==1 [aw=CIemp2_2007] , cluster(state) absorb(fips)

*Providing results by geog. concentration percentiles with Delta method (in text)
use "$ecpublic\miansufieconometrica_countyindustrylevel", clear
gen netwpherf_b=Iherf*netwp_h
keep if netwp_h!=. & CIemp2_0709!=.
*creating weighted percentiles
sort Iherf
egen Iherf_group=group(Iherf)
egen indtag=tag(industry)
gen temp=1 if indtag==1 & Iemp2_2007!=.
sort Iherf
gen runsumemp=sum(Iemp2_2007*temp)
egen totsumemp=sum(Iemp2_2007*temp)
gen Ipercentile=runsumemp/totsumemp /*percentile of industry by geog concentration and percentiles weighted by employment*/
gen Ipercentile_10=int(Ipercentile*10)+1
replace Ipercentile_10=10 if Ipercentile_10==11
*predictnl uses the Delta method to compute standard errors.
*table 5, col 5
reg CIemp2_0709 netwp_h Iherf netwpherf_b [aw=CIemp2_2007] , cluster(state)
predictnl cf5_new=_b[netwp_h]+Iherf*_b[netwpherf], se(se5_new)
l cf5_new se5_new Ipercentile if indtag==1


*******************************************
***** Table 6: Wage Deflation/Mobility ****
*******************************************
use "$ecpublic\miansufieconometrica_countylevel", clear
reg Cwage_0709 netwp_h [aw=total], cluster(state) robust
reg Cwage_0709 netwp_h C2D06share* [aw=total], cluster(state) robust
reg Cwagehr_Wmean0709 netwp_h [aw=total], robust cluster(state)
reg Cwagehr_Wmean0709 netwp_h C2D06share* [aw=total], robust cluster(state)
gen pop0709=log(pop2009)-log(pop2007)
reg pop0709 netwp_h [aw=total], robust cluster(state)
reg pop0709 netwp_h C2D06share* [aw=total], robust cluster(state)
reg Cmovest0709 netwp_h [aw=total], robust
reg Cmovest0709 netwp_h C2D06share* [aw=total], robust
reg Clf_0709 netwp_h [aw=total], cluster(state) robust
reg Clf_0709 netwp_h C2D06share* [aw=total], robust cluster(state)


********************
**APPENDIX**********
********************

****************************************************
*****  Appendix Table 1: Industry Classification ***
****************************************************
use "$ecpublic\miansufieconometrica_countyindustrylevel", clear
egen ntag=tag(naics)
keep if ntag==1
keep if Iemp2_2007!=.
egen totalemp=sum(Iemp2_2007)
gen Iempshare07=(Iemp2_2007/totalemp)*100
sort indcat nontradable_strict Iempshare07 naics
replace Iherf=Iherf*100
keep indcat nontradable_strict naics industry Iempshare07 Iherf
outsheet using "$output\AppendiTable1_industrylist.csv", comma replace


*********************************************************
*****  Appendix Table 2: State budget and uncertainty
*********************************************************
use "$ecpublic\Sshoagtests", clear
egen cutspc_0709=rmean(cutspc_2007-cutspc_2009)
reg CCemp2_0709 netwp_h [aw=total]  if indcat==2
reg CCemp2_0709 cutspc_0709 [aw=total] if indcat==2
reg CCemp2_0709 netwp_h cutspc_0709 [aw=total] if indcat==2


******************************************
**** Appendix FIGURE 1:  NFIB time series 
******************************************
use "$ecpublic\emppop", clear
expand 12
sort year
by year: gen month=_n
gen emppop=jan if month==1
replace emppop=feb if month==2
replace emppop=mar if month==3
replace emppop=apr if month==4
replace emppop=may if month==5
replace emppop=jun if month==6
replace emppop=jul if month==7
replace emppop=aug if month==8
replace emppop=sep if month==9
replace emppop=oct if month==10
replace emppop=nov if month==11
replace emppop=dec if month==12
keep year month emppop
rename month m
gen month=monthly(string(year)+"m"+string(m), "YM")
format month %tm
gen quarter=qofd(dofm(month))
format quarter %tq
sort quarter month
by quarter: keep if _n==_N
keep quarter emppop
sort quarter
label var emppop "Employment to population ratio"
tempfile tempemppop
save "`tempemppop'", replace
use "$ecpublic\Qnfib", clear
gen govtax=taxes+gov
label var govtax "Regulation and taxes"
sort quarter
merge 1:1 quarter using "`tempemppop'"
keep if _merge==1 | _merge==3
# delimit ;
graph twoway 
(line poorsales govtax financing quarter if quarter>=169, lp(dash longdash shortdash)) 
(line emppop quarter if quarter>=169, lp(solid) lc(black) yaxis(2)),
title("Business Concerns and Employment", size(large))
ylabel(,labsize(small) axis(1))
ylabel(,labsize(small) axis(2))
xtitle("", size(small)) 
ytitle("Fraction stating concern", size(small) axis(1))
ytitle("Employment to poulation ratio", size(small) axis(2))
legend(size(small) rows(4));
# delimit cr


****************************************
***** Appendix Figure 2: NFIB CROSS-SECTION
****************************************
use "$ecpublic\nfibcs", clear
# delimit ;
graph twoway 
(scatter poorsales0609 netwp_h, mlabel(statesh) msize(tiny) 
xtitle("Change in housing net worth, 2006-2009") 
ytitle("Change in businesses citing" "poor sales as top concern, 06-09")) 
(lfit poorsales0609 netwp_h, legend(off));
graph save "$output\Figure3a", replace;

graph twoway 
(scatter govtax0609 netwp_h, mlabel(statesh) msize(tiny) 
xtitle("Change in housing net worth, 2006-2009") 
ytitle("Change in businesses citing" "regulation & taxes as top concern, 06-09")) 
(lfit govtax0609 netwp_h, legend(off));
graph save "$output\Figure3b", replace;

graph combine "$output\Figure3a" "$output\Figure3b" 
, col(1) xsize(4) ysize(5.5);
graph save "$output\Figure3", replace;
# delimit cr


*********************************************************
*****  Appendix Figure 3: State budget and uncertainty
*********************************************************
use "$ecpublic\SYshoagtests", clear
collapse (mean) cutspc cl, by(year)
label var cutspc "Mid-year budget cuts, per capita"
label var cl "CoreLogic house price index"
graph twoway (line cutspc year, lp(solid) lw(thick)) (line cl year, lp(dash) lw(thick) yaxis(2)), xsize(7) ysize(4) title("House prices and state budget cuts") legend(rows(2))

